@@ -12,7 +12,7 @@ prompt = "C:\>"
 
 while True:
     command = input(prompt)
-    cCode = "python3 " + pydosPath + command + ".py"
+    cCode = pydosPath + command + ".py"
     if command == "exit":
         print("Bye")
         break
